@@ -25,13 +25,21 @@ import time
 
 
 __author__ = 'Daniel Lindsley'
-__version__ = (1, 0, 0)
+__version__ = (1, 0, 1)
 __license__ = 'BSD'
 
 
 class Timer(object):
     """
     A context manager that times the code it wraps.
+
+    Usage::
+
+        with Timer() as timed:
+            # Code goes here.
+
+        print(timed.elapsed)
+
     """
     def __init__(self):
         self.start = None
